/*++

Copyright (c) 2010-2013 ELMOS Co., Ltd.

Module Name:
	EPX64S.h
Abstract:
	EPX-64S API library definitions
Revision History:
	10/05/28	Created.
	11/12/22	Modified response time.
	13/05/01	Support for Windows 8.

--*/

#ifndef EPX64S_H
#define EPX64S_H

#ifdef EPX64S_EXPORTS_
#define EPX64S_API __declspec(dllexport)
#else
#define EPX64S_API __declspec(dllimport)
#endif

//
// Device handle
//
typedef void *EPX64S_HANDLE;

//
// Device status (Return Value)
//
enum {
    EPX64S_OK,
    EPX64S_INVALID_HANDLE,
    EPX64S_DEVICE_NOT_FOUND,
    EPX64S_DEVICE_NOT_OPENED,
	EPX64S_OTHER_ERROR,
	EPX64S_COMMUNICATION_ERROR,
    EPX64S_INVALID_PARAMETER
};

//
// Constants
//
#define EPX64S_PORT0	0x01
#define EPX64S_PORT1	0x02
#define EPX64S_PORT2	0x04
#define EPX64S_PORT3	0x08
#define EPX64S_PORT4	0x10
#define EPX64S_PORT5	0x20
#define EPX64S_PORT6	0x40
#define EPX64S_PORT7	0x80

#ifdef __cplusplus
extern "C" {
#endif

//
// Function definitions
//
EPX64S_API int WINAPI EPX64S_GetNumberOfDevices (int *Number);
EPX64S_API int WINAPI EPX64S_GetSerialNumber (int Index, int *SerialNumber);
EPX64S_API int WINAPI EPX64S_Open (EPX64S_HANDLE *Handle);
EPX64S_API int WINAPI EPX64S_OpenBySerialNumber (int SerialNumber, EPX64S_HANDLE *Handle);
EPX64S_API int WINAPI EPX64S_Close (EPX64S_HANDLE Handle);

EPX64S_API int WINAPI EPX64S_SetDirection (EPX64S_HANDLE Handle, BYTE Direction);
EPX64S_API int WINAPI EPX64S_GetDirection (EPX64S_HANDLE Handle, BYTE *Direction);
EPX64S_API int WINAPI EPX64S_OutputPort (EPX64S_HANDLE Handle, BYTE Port, BYTE Value);
EPX64S_API int WINAPI EPX64S_InputPort (EPX64S_HANDLE Handle, BYTE Port, BYTE *Value);

#ifdef __cplusplus
}
#endif

#endif  /* EPX64S_H */